/*----------------------------------------------------------------------------------*/
/*	Copyright (C) Endress+Hauser Metechnik GmbH+Co (2001). All Rights Reserved		*/
/*	Product:		SIMATIC PDM														*/
/*                                                          						*/
/*	Device:			DIFFERENCE PRESSURE DEVICE for HART	DELTABAR-S					*/
/*	Description:	Device Description												*/
/*	Dictionary:		SIPADC01.dct, EHHA__Deltabar_00.dct								*/
/*                                                          						*/
/*  $Revision:1.3$	 																	*/
/*  $Date:05.04.2002$															*/
/*  Obere Revision fr QVCS, untere fr DD, unten die aktuelle angeben 		*/ 
/*  Revision:1.3	 							*/
/*  Date:05.04.2002								*/
/*----------------------------------------------------------------------------------*/
/* Date:                23.05.2001													*/
/* Author:              J. Flegel / ICS GmbH										*/
/* Changed Function(s): Change001 vollstndig berarbeitet							*/
/*----------------------------------------------------------------------------------*/
/* Date:                30.05.2001													*/
/* Author:              J. Flegel / ICS GmbH										*/
/* Changed Function(s): Deltabar V5.0 / V7.0 im gleichen Verzeichnis(Namen angepat)*/
/*						Change002 Menebene matrix_parameters entfllt; Auswahl V3H0*/
/*						korrigiert; Felder V31-V35 nicht sichtbar, wenn V30==Druck; */
/*						BarVal_process_display entfernt; default_values als Auswahl-*/
/*						liste; Menu_system_units => OnlineDialog_system_units;		*/
/*						nderungen im Dictionary									*/
/*----------------------------------------------------------------------------------*/
/* Date:                13.06.2001													*/
/* Author:              J. Flegel / ICS GmbH										*/
/* Changed Function(s): Change003 V3H0 als Verweis; Werkswerte (default_values)		*/
/*						Auswahl-Codes sortiert; Gertemen sortiert					*/
/*----------------------------------------------------------------------------------*/
/* Date:                05.04.2002                                              */
/* Version:		1.3							*/
/* Author:              F.Birgel / PCPS     					*/
/* Changed Function(s): HART Standardansicht eingefhrt				*/
/*------------------------------------------------------------------------------*/
MANUFACTURER	ENDRESS_HAUSER,
DEVICE_TYPE		_DELTBS,
DEVICE_REVISION 5,
DD_REVISION		1

/************************************************************************************/
/*    Macros																		*/
/************************************************************************************/
#define STATUS_SIZE				3		/* size of status array				  */
#define STATUS_RESPONSE_CODE	0
#define BI_SUCCESS		0				/* task succeeded in intended task	  */

/************************************************************************************/
/*    PDM-Menus																		*/
/************************************************************************************/
//#define DEBUG_OPTION1	OfflineDialog_DebugDeviceIdentification

#include "SIHA.inc"
#include "SI_FileM.inc"
#include "SI_HlpM.inc"
#include "SI_OptM.inc"

/*Change003 start*/
#define EXTRA_ITEMS_DEVICE_MENU_SPECIALIST						\
		OnlineDialog_hart_comm,				\
		std_CommWay,					\
		OnlineDialog_burst_mode,			\
		configuration_flag_reset,			\
		SEPARATOR,												\
		OnlineDialog_simulation,								\
		OnlineDialog_linear,									\
		Menu_procedures,										\
		OnlineDialog_system_units,	/*Change002*/				\
		SEPARATOR,												\
		CALIBRATION,											\
		OnlineDialog_int_count_high,							\
		OnlineDialog_default_values,							\
		OnlineDialog_linearisation_mode,						\
		OnlineDialog_security_locking							\

/*Change003 end*/

#include "SI_DevM.inc"

#define EXTRA_ITEMS_VIEW_MENU_SPECIALIST	\
		OnlineWindow_diagnosis,		\
		OnlineWindow_indicator

#define EXTRA_ITEMS_VIEW_MENU_MAINTENANCE	\
		OnlineWindow_diagnosis,		\
		OnlineWindow_indicator
#include "SI_ViewM.inc"

/************************************************************************************/
/*    HCF-Import												   					*/
/************************************************************************************/
#include "EHHA__Deltabar_00.inc"

/************************************************************************************/
/*    Trending													   					*/
/************************************************************************************/

#define YT1_LABEL	[menu_dialog_display_measure]
#define YT1_VALUE	measured_parameter
#define	YT1_LRV		lower_range_value
#define YT1_URV		upper_range_value

#define YT2_LABEL	sensor_pressure.LABEL
#define YT2_VALUE	sensor_pressure
#define	YT2_LRV		lower_range_value
#define YT2_URV		upper_range_value

#define YT3_LABEL	damped_pressure.LABEL
#define YT3_VALUE	damped_pressure
#define	YT3_LRV		lower_range_value
#define YT3_URV		upper_range_value

#define YT4_LABEL	bias_damped_pressure.LABEL
#define YT4_VALUE	bias_damped_pressure
#define	YT4_LRV		lower_range_value
#define YT4_URV		upper_range_value

#include "SI_YT.inc"

/************************************************************************************/
/*		Refresh relations															*/
/************************************************************************************/

/*******************************************************************************/
/*****	MENU Bar  **************************************************************/
/*******************************************************************************/

METHOD std_CommWay
{
	LABEL		[menu_Device_CommWay];
	DEFINITION
	{
	}
}

MENU Menu_Main_Specialist
{
	LABEL		[main_menu];
	ITEMS
	{
		Menu_File,
		Menu_S_Device,
		Menu_S_View,
		Menu_S_Options,
		Menu_Help
	}
}

MENU Menu_Main_Maintenance
{
	LABEL		[main_menu];
	ITEMS
	{
		Menu_File,
		Menu_M_Device,
		Menu_M_View,
		Menu_M_Options,
		Menu_Help
	}
}

/*******************************************************************************/
/*****	Online-Windows  ********************************************************/
/*******************************************************************************/

MENU OnlineWindow_display
{
	LABEL		[menu_dialog_display];
	ITEMS
	{
		Page_display_overview,
		Page_display_pressure
	}
}

MENU Page_display_overview
{
	LABEL	[menu_dialog_overview];
	ITEMS
	{
		BarVal_process_display,

		Val_temperature_value,

		switch_sim					(READ_ONLY)
		Val_analog_value,
		Val_percent_range,

		device_status	(READ_ONLY)
	}
}

MENU Page_display_pressure
{
	LABEL	[menu_pressure];
	ITEMS
	{
		//Change002: BarVal_process_display entfernt

		Val_sensor_pressure,
		Val_damped_pressure,
		Val_bias_damped_pressure,
		
		device_status	(READ_ONLY),
	}
}

MENU BarVal_process_display
{
	LABEL		measured_parameter.LABEL;
	ITEMS
	{
			measured_parameter,	 	
//Change002 start
			IF (linearisation_mode == 0)
			{
				lower_range_value	(READ_ONLY),
				upper_range_value	(READ_ONLY)
			}
			ELSE
			{
				display_at_04	(READ_ONLY),
				display_at_20	(READ_ONLY)
			}
//Change002 end
	}
}

MENU Val_sensor_pressure
{
    LABEL           sensor_pressure.LABEL;
	HELP			sensor_pressure.HELP;
	ITEMS
	{
		sensor_pressure (READ_ONLY),
	}
}

MENU Val_damped_pressure
{
    LABEL           damped_pressure.LABEL;
	HELP			damped_pressure.HELP;
	ITEMS
	{
		damped_pressure (READ_ONLY),
	}
}

MENU Val_bias_damped_pressure
{
    LABEL           bias_damped_pressure.LABEL;
	HELP			bias_damped_pressure.HELP;
	ITEMS
	{
		bias_damped_pressure (READ_ONLY),
	}
}

MENU Val_temperature_value
{
    LABEL           temperature_value.LABEL;
	HELP			temperature_value.HELP;
	ITEMS
	{
		temperature_value (READ_ONLY),
	}
}

MENU Val_analog_value
{
    LABEL           output_current.LABEL;
	HELP			[analog_value_help];
	ITEMS
	{
		output_current (READ_ONLY),  /* Output Current */
	}
}

MENU Val_percent_range
{
    LABEL           percent_range.LABEL;
	HELP			percent_range.HELP;
	ITEMS
	{
		percent_range (READ_ONLY)
	}
}

MENU OnlineWindow_indicator
{
    LABEL	[menu_indicator];
    ITEMS
    {
			Page_press_indicator,
			Page_temp_indicator
    }
}

MENU Page_press_indicator
{
    LABEL	[menu_pressure];
    ITEMS
    {
		Val_sensor_pressure,
		Group_press_indicator
    }
}

MENU Group_press_indicator
{
    LABEL	[menu_indicator];
    ITEMS
    {
		sensor_pressure_min			(READ_ONLY),
		sensor_pressure_max			(READ_ONLY),
		reset_pressure_pointer
    }
}

MENU Page_temp_indicator
{
    LABEL	[menu_temp];
    ITEMS
    {
		Val_temperature_value
		Group_temp_indicator
    }
}

MENU Group_temp_indicator
{
    LABEL	[menu_indicator];
    ITEMS
    {
		temperature_value_min		(READ_ONLY),
		temperature_value_max		(READ_ONLY),
		reset_temperature_pointer
    }
}


MENU OnlineWindow_diagnosis
{
	LABEL		[menu_dialog_diagnosis];
	ITEMS
	{
		Page_diagnosis_device,
		Page_diagnosis_status,
	}
}

MENU Page_diagnosis_device
{
	LABEL		[menu_ident_device];
	ITEMS
	{
			tag						(READ_ONLY),					
			manufacturer_id			(READ_ONLY),
			device_type				(READ_ONLY),
			device_id				(READ_ONLY),
			date					(READ_ONLY),							
			universal_revision		(READ_ONLY),
			transmitter_revision	(READ_ONLY),
			hardware_revision		(READ_ONLY),
			software_revision		(READ_ONLY),
			final_assembly_number	(READ_ONLY),
			write_protect			(READ_ONLY)
	}
}


MENU Page_diagnosis_status
{
	LABEL	[menu_status];
	ITEMS
	{
		switch_sim				(READ_ONLY),
		device_status			(READ_ONLY),
		diagnostic_code			(READ_ONLY),
		last_diagnostic			(READ_ONLY),
		xmtr_specific_status_0	(READ_ONLY),
		xmtr_specific_status_1	(READ_ONLY),
		int_count_high			(READ_ONLY),
	}
}


/*******************************************************************************/
/*****	Online-Dialogs  ********************************************************/
/*******************************************************************************/

MENU OnlineDialog_burst_mode
{
	LABEL		[menu_burst_mode];
	ITEMS
	{
			burst_mode_select,
			burst_command_number,
			sie_set
	}
}

MENU Menu_procedures
{
	LABEL		[menu_procedures];
	ITEMS
	{   
		OnlineDialog_automatic_4mA,
		OnlineDialog_automatic_20mA,
		OnlineDialog_bias_pressure,
		OnlineDialog_low_sensor_cal,
		OnlineDialog_high_sensor_cal,
	}
}

//Change002 start: Menu_system_units siehe OnlineDialog_system_units
MENU OnlineDialog_system_units
{
	LABEL		[menu_system_units];
	ITEMS
	{
		pressure_unit_edit,
		lin_units_edit,
		temperature_units_edit
	}
}
//Change002 end

MENU OnlineDialog_bias_pressure
{
	LABEL		local_automatic_bias_V0H6.LABEL;//bias_pressure.LABEL;
	ITEMS
	{
			bias_pressure	(READ_ONLY),
			automatic_bias,
	}
}

MENU OnlineDialog_automatic_4mA
{
	LABEL		local_automatic_4mA_V0H3.LABEL;//lower_range_value.LABEL;
	ITEMS
	{
		lower_range_value	(READ_ONLY),
		automatic_4mA,
	}
}

MENU OnlineDialog_automatic_20mA
{
	LABEL		local_automatic_20mA_V0H4.LABEL;//upper_range_value.LABEL;
	ITEMS
	{
		upper_range_value	(READ_ONLY),
		automatic_20mA,
	}
}

MENU OnlineDialog_low_sensor_cal
{
	LABEL		low_sensor_cal.LABEL;
	ITEMS
	{
		damped_pressure		(READ_ONLY), //V3H7
		low_sensor_cal		(READ_ONLY), //V7H4
		automatic_low_sensor_cal,
	}
}

MENU OnlineDialog_high_sensor_cal
{
	LABEL		high_sensor_cal.LABEL;
	ITEMS
	{
		damped_pressure		(READ_ONLY), //V3H7
		high_sensor_cal		(READ_ONLY), //V7H5
		automatic_high_sensor_cal,
	}
}

MENU OnlineDialog_simulation
{
	LABEL		[menu_interface_simulate];
    ITEMS
    {   
		output_current	(READ_ONLY),
        sim_current,
		SEPARATOR,
		switch_sim		(READ_ONLY),
		abort_simulation
    }
}


MENU OnlineDialog_linear
{
	LABEL		[menu_linearisation_mode];
    ITEMS
    {   
        Page_linearization_read,
		Page_linearization_input
    }
}

MENU Page_linearization_read
{
	LABEL		[menu_dialog_linearization_read];
    ITEMS
    {   
		Group_linearization_status,
        linearization_edit_mode	(READ_ONLY),
        xy_table_index,
		xy_table_X				(READ_ONLY),
		xy_table_Y				(READ_ONLY),
		meth_read
    }
}

MENU Page_linearization_input
{
	LABEL		[menu_dialog_linearization_input];
    ITEMS
    {   
		Group_linearization_status,
        linearization_edit_mode,
        xy_table_index,
		IF (linearization_edit_mode == 1)
		{
			xy_table_X,
		}
		ELSE
		{
			xy_table_X	(READ_ONLY),
		}
		IF (linearization_edit_mode == 1 || linearization_edit_mode == 2)
		{
			xy_table_Y,
		}
		ELSE
		{
			xy_table_Y	(READ_ONLY),
		}
    }
}

MENU Group_linearization_status
{
	LABEL		[diag_status];
	ITEMS
	{
		diagnostic_code,
		last_diagnostic	(READ_ONLY)
	}
}

METHOD meth_read
{
	LABEL	[meth_read];
	DEFINITION
	{}
}

//Change002 OnlineDialog_pressure_unit_edit,
//			OnlineDialog_temperature_units_edit,
//			OnlineDialog_lin_units_edit siehe OnlineDialog_system_units

MENU OnlineDialog_int_count_high
{
	LABEL		int_count_high.LABEL;
	ITEMS
	{
			int_count_high
	}
}

MENU OnlineDialog_linearisation_mode
{
	LABEL		linearisation_mode.LABEL;
	ITEMS
	{
			linearisation_mode
	}
}

MENU OnlineDialog_default_values
{
	LABEL		[V2H9_LABEL_change];
	ITEMS
	{
			default_values
	}
}

MENU OnlineDialog_security_locking
{
	LABEL		[V9H9_LABEL_change]; //Change003
	ITEMS
	{
			Page_security_locking
	}
}

MENU Page_security_locking
{
	LABEL		[menu_security_locking];
	ITEMS
	{
			write_protect (READ_ONLY),
			security_locking,
	}
}


/*******************************************************************************/
/*****	Parameter table  ********************************************************/
/*******************************************************************************/
//start Bi Menu changes
MENU Table_Main_Specialist
{
	LABEL	"Deltabar S";
	ITEMS
	{
		Tab_s_EH_Std_Matrix
		Tab_s_HART_Menu
	}
}

MENU Table_Main_Maintenance
{
	LABEL	"Deltabar S";
	ITEMS
	{
		Tab_m_EH_Std_Matrix,
		Tab_m_HART_Menu
	}
}

MENU Tab_s_HART_Menu
{
	LABEL	[label_HART_Menu];
	ITEMS
	{
		Tab_s_ident
	}
}

MENU Tab_m_HART_Menu
{
	LABEL	[label_HART_Menu];
	ITEMS
	{
		Tab_m_ident
	}
}

MENU Tab_s_ident
{
	LABEL		[menu_ident];
	ITEMS
	{	
		Tab_s_ident_opunit1,	
		Tab_s_ident_device
	}
}

MENU Tab_m_ident
{
	LABEL		[menu_ident];
	ITEMS
	{	
		Tab_m_ident_opunit1,	
		Tab_m_ident_device
	}
}

MENU Tab_s_ident_opunit1
{
	LABEL		[menu_ident_opunit];
	ITEMS
	{
		tag,
		message,
		descriptor
	}
}

MENU Tab_m_ident_opunit1
{
	LABEL		[menu_ident_opunit];
	ITEMS
	{
		tag(READ_ONLY),
		message(READ_ONLY),
		descriptor(READ_ONLY)
	}
}

MENU Tab_s_ident_device
{
	LABEL	[menu_ident_device];
	ITEMS
	{
		manufacturer_id (READ_ONLY),
		device_type (READ_ONLY),
		device_id (READ_ONLY),
		universal_revision (READ_ONLY),
		transmitter_revision (READ_ONLY),
		software_revision (READ_ONLY),
		hardware_revision (READ_ONLY),
		device_flags (READ_ONLY),
		physical_signaling_code (READ_ONLY),
		final_assembly_number,
		write_protect (READ_ONLY),
		date
	}
}

MENU Tab_m_ident_device
{
	LABEL	[menu_ident_device];
	ITEMS
	{
		manufacturer_id (READ_ONLY),
		device_type (READ_ONLY),
		device_id (READ_ONLY),
		universal_revision (READ_ONLY),
		transmitter_revision (READ_ONLY),
		software_revision (READ_ONLY),
		hardware_revision (READ_ONLY),
		device_flags (READ_ONLY),
		physical_signaling_code (READ_ONLY),
		final_assembly_number (READ_ONLY),
		write_protect (READ_ONLY),
		date (READ_ONLY)
	}
}
//end Bi Menu changes



MENU Tab_s_EH_Std_Matrix
{
	LABEL	[menu_table_EH_Std_Matrix];
	ITEMS
	{
//Change002 start
		CALIBRATION,                                                  /* MENUE */
		TRANSMITTER_INFO,                                             /* MENUE */
		LINEARIZATION,                                                /* MENUE */
		ADDITIONAL_FUNCTION,                                          /* MENUE */
		MEN_SERVICE,
		USER_INFORMATION                                              /* MENUE */
//Change002 end
	}
}

MENU Tab_m_EH_Std_Matrix
{
	LABEL	[menu_table_EH_Std_Matrix];
	ITEMS
	{
//Change002 start
		CALIBRATION_m,                                                  /* MENUE */
		TRANSMITTER_INFO_m,                                             /* MENUE */
		LINEARIZATION_m,                                                /* MENUE */
		ADDITIONAL_FUNCTION_m,                                          /* MENUE */
		MEN_SERVICE_m,
		USER_INFORMATION_m                                              /* MENUE */
//Change002 end
	}
}

//Change002: matrix_parameters_m entfernt; ITEMS siehe Tab_m_EH_Std_Matrix

CALIBRATION_m LIKE MENU CALIBRATION
{
	 REDEFINE ITEMS
	 {
		  measured_parameter,                                        /* VARIABLE */
		  lower_range_value	(READ_ONLY),                             /* VARIABLE */
		  upper_range_value	(READ_ONLY),                             /* VARIABLE */
		  local_automatic_4mA_V0H3, //automatic_4mA					 /* METHOD   */
		  local_automatic_20mA_V0H4, //automatic_20mA				 /* METHOD   */
		  bias_pressure 	(READ_ONLY),                             /* VARIABLE */
		  local_automatic_bias_V0H6, //automatic_bias,               /* METHOD   */
		  pressure_damping(READ_ONLY),                              /* VARIABLE */
		  alarm_selection_code_1(READ_ONLY),                        /* VARIABLE */
		  local_pressure_unit_edit,									 /* VARIABLE */
	 }
  }

TRANSMITTER_INFO_m LIKE MENU TRANSMITTER_INFO
{
	 REDEFINE ITEMS
	 {
		diagnostic_code,                                           /* VARIABLE */
		last_diagnostic(READ_ONLY),		// VARIABLE , last_diag_meth,					
		instr_and_softw_no,                                        /* VARIABLE */
		local_sensor_pressure_min,	// VARIABLE , sensor_pres_min_meth,
		local_sensor_pressure_max,	// VARIABLE , sensor_pres_max_meth,
		local_int_count_high,		// VARIABLE , int_count_high_meth,
		temperature_value,                                         /* VARIABLE */
		local_temperature_value_min,// VARIABLE , temp_value_min_meth,
		local_temperature_value_max,// VARIABLE , temp_value_max_meth,
		local_default_values										 /* VARIABLE */
	 }
  }

LINEARIZATION_m LIKE MENU LINEARIZATION
{
	 REDEFINE ITEMS
	 {
		local_linearisation_mode, //Change003                           /* VARIABLE */
		display_at_04		(READ_ONLY),                               /* VARIABLE */
		display_at_20		(READ_ONLY),                               /* VARIABLE */
		local_lin_units_edit,//lin_units_edit,                         /* VARIABLE */
		density_factor		(READ_ONLY),                               /* VARIABLE */
		creep_flow_supppress(READ_ONLY),                               /* VARIABLE */
		local_linearization_edit_mode,                                 /* VARIABLE */
		local_xy_table_index,                                          /* VARIABLE */
		local_xy_table_X,                                              /* VARIABLE */
		local_xy_table_Y                                               /* VARIABLE */
	 }
}

ADDITIONAL_FUNCTION_m LIKE MENU ADDITIONAL_FUNCTION
{
	 REDEFINE ITEMS
	 {
		output_current,                                            /* VARIABLE */
		//sim_current											   /* METHOD   */
		local_switch_sim,
		local_simulation_current,
		current_low_limit(READ_ONLY),                              /* VARIABLE */
		local_automatic_low_sensor_cal,  //automatic_low_sensor_cal/* METHOD   */
		local_automatic_high_sensor_cal,//automatic_high_sensor_cal/* METHOD   */
		sensor_lower_limit,                                        /* VARIABLE */
		sensor_upper_limit,                                        /* VARIABLE */
		sensor_pressure,                                           /* VARIABLE */
		local_temperature_units_edit                               /* VARIABLE */
	 }
}

MEN_SERVICE_m LIKE MENU MEN_SERVICE
{
	 REDEFINE ITEMS
	 {
		damped_pressure,                                               /* VARIABLE */
		bias_damped_pressure,                                          /* VARIABLE */
		security_locking		 (READ_ONLY)		                     /* VARIABLE */
	 }
}

USER_INFORMATION_m LIKE MENU USER_INFORMATION
{
	 REDEFINE ITEMS
	 {
		matrix_par1.tag,										/* VARIABLE */
		matrix_par1.user_text,									/* VARIABLE */
		matrix_par1.serial_number,								/* VARIABLE */
		matrix_par1.sensor_serial_number_matrix,				/* VARIABLE */
		matrix_par1.process_connection_p (READ_ONLY),           /* VARIABLE */
		matrix_par1.process_connection_m (READ_ONLY),           /* VARIABLE */
		matrix_par1.gasket (READ_ONLY),                         /* VARIABLE */
		matrix_par1.process_diaphragma (READ_ONLY),             /* VARIABLE */
		matrix_par1.fill_liquit (READ_ONLY)                     /* VARIABLE */
	 }
}


/*******************************************************************************/
/*****	Methods		************************************************************/
/*******************************************************************************/

METHOD method_set
{
	LABEL		[transfer];
	HELP		[transfer_help];
	DEFINITION
	{
	}
}


/***********************************************************************/
/*    Unit relations                                                   */
/***********************************************************************/

