/*----------------------------------------------------------------------------------*/
/*	Copyright (C) Endress+Hauser Metechnik GmbH+Co (2001). All Rights Reserved		*/
/*	Product:		SIMATIC PDM														*/
/*                                                          						*/
/*	Device:			Pressure transmitter for HART									*/
/*	Description:	Device Description. Part to import HCF-DD						*/
/*	Dictionary:		SIPADC01.dct													*/
/*                                                          						*/
/*  $Revision:1.3$	 																	*/
/*  $Date:05.04.2002$															*/
/*  Obere Revision fr QVCS, untere fr DD, unten die aktuelle angeben 		*/ 
/*  Revision:1.3	 							*/
/*  Date:05.04.2002								*/
/*----------------------------------------------------------------------------------*/
/* Date:                23.05.2001													*/
/* Author:              J. Flegel / ICS GmbH										*/
/* Changed Function(s): Change001 vollstndig berarbeitet							*/
/*----------------------------------------------------------------------------------*/
/* Date:                30.05.2001													*/
/* Author:              J. Flegel / ICS GmbH										*/
/* Changed Function(s): Deltabar V5.0 / V7.0 im gleichen Verzeichnis(Namen angepat)*/
/*						Change002 Menebene matrix_parameters entfllt; Auswahl V3H0*/
/*						korrigiert; Felder V31-V35 nicht sichtbar, wenn V30==Druck; */
/*						BarVal_process_display entfernt; default_values als Auswahl-*/
/*						liste; Menu_system_units => OnlineDialog_system_units;		*/
/*						nderungen im Dictionary									*/
/*----------------------------------------------------------------------------------*/
/* Date:                13.06.2001													*/
/* Author:              J. Flegel / ICS GmbH										*/
/* Changed Function(s): Change003 V3H0 als Verweis; Werkswerte (default_values)		*/
/*						Auswahl-Codes sortiert; Gertemen sortiert					*/
/*----------------------------------------------------------------------------------*/
/* Date:                05.04.2002                                              */
/* Version:		1.3							*/
/* Author:              F.Birgel / PCPS     					*/
/* Changed Function(s): HART Standardansicht eingefhrt				*/
/*------------------------------------------------------------------------------*/

/*****************************************************************************/
/* Defines in Import-Source:                                                 */
/* IMPORT ENDRESS_HAUSER _DELTBS, DEVICE_REVISION 5, DD_REVISION 1			 */
/*****************************************************************************/

#define prompt_process     "Current applied process value:       >%{0} %{1}"\
                       "|049Jetzt anliegender Prozesswert:       >%{0} %{1}"

#define select_4mA         "Set as 4 mA value;Read new value"\
                       "|049Als 4 mA setzen;Wert neu einlesen"

#define select_20mA        "Set as 20 mA value;Read new value"\
                       "|049Als 20 mA setzen;Wert neu einlesen"

#define select_bias        "Set as bias value;Read new value"\
                       "|049Als BIAS-Druck setzen;Wert neu einlesen"

#define prompt_pressure    "Current applied sensor pressure:     >%{0} %{1}"\
                       "|049Jetzt anliegender Sensordruck:       >%{0} %{1}"

#define select_LSC         "Set as LSC value;Read new value"\
                       "|049Als LSC-Druck setzen;Wert neu einlesen"

#define select_HSC         "Set as HSC value;Read new value"\
                       "|049Als HSC-Druck setzen;Wert neu einlesen"

#define prompt_low_sens    "LOW SENSOR CAL.      DAMPED PRESSURE      >%{0} %{1}"\
                       "|049LOW SENSOR CAL.      GEDMPFTER DRUCK     >%{0} %{1}"

#define prompt_high_sens   "HIGH SENSOR CAL.     DAMPED PRESSURE      >%{0} %{1}"\
                       "|049HIGH SENSOR CAL.     GEDMPFTER DRUCK     >%{0} %{1}"

#define prompt_reset       "Reset value?"\
                       "|049Wert zuruecksetzen?"

#define yes_or_no          "Yes;No"\
                       "|049Ja;Nein"

#define pressure_format  SELECT (format)      \
                         {                    \
                            CASE 0  : "6.0f"; \
                            CASE 1  : "7.1f"; \
                            CASE 2  : "7.2f"; \
                            CASE 3  : "7.3f"; \
                            CASE 4  : "7.4f"; \
                            DEFAULT : "6.0f"; \
                         }

#define DEF_DIAGNOSTIC_CODE							\
	{0,   [E0_DeltaBarS],	[E0_DeltaBarS_Help]},	\
	{101, [E101_DeltaBarS], [E101_DeltaBarS_Help]}, \
	/*{102, [E102_DeltaBarS], [E102_DeltaBarS_Help]},*/ \
	{103, [E103_DeltaBarS], [E103_DeltaBarS_Help]}, \
	{104, [E104_DeltaBarS], [E104_DeltaBarS_Help]}, \
	{106, [E106_DeltaBarS], [E106_DeltaBarS_Help]}, \
	{110, [E110_DeltaBarS], [E110_DeltaBarS_Help]}, \
	{111, [E111_DeltaBarS], [E111_DeltaBarS_Help]}, \
	{112, [E112_DeltaBarS], [E112_DeltaBarS_Help]}, \
	{113, [E113_DeltaBarS], [E113_DeltaBarS_Help]}, \
	{114, [E114_DeltaBarS], [E114_DeltaBarS_Help]}, \
	{115, [E115_DeltaBarS], [E115_DeltaBarS_Help]}, \
	{116, [E116_DeltaBarS], [E116_DeltaBarS_Help]}, \
	/*{118, [E118_DeltaBarS], [E118_DeltaBarS_Help]},*/	\
	{120, [E120_DeltaBarS], [E120_DeltaBarS_Help]}, \
	{602, [E602_DeltaBarS], [E602_DeltaBarS_Help]}, \
	{604, [E604_DeltaBarS], [E604_DeltaBarS_Help]}, \
	{605, [E605_DeltaBarS], [E605_DeltaBarS_Help]},	\
	/*{610, [E610_DeltaBarS], [E610_DeltaBarS_Help]},*/	\
	{613, [E613_DeltaBarS], [E613_DeltaBarS_Help]},	\
	{620, [E620_DeltaBarS], [E620_DeltaBarS_Help]},	\
	/*{670, [E670_DeltaBarS], [E670_DeltaBarS_Help]},*/	\
	{672, [E672_DeltaBarS], [E672_DeltaBarS_Help]},	\
	{673, [E673_DeltaBarS], [E673_DeltaBarS_Help]},	\
	{674, [E674_DeltaBarS], [E674_DeltaBarS_Help]},	\
	/*{675, [E675_DeltaBarS], [E675_DeltaBarS_Help]},*/	\


IMPORT ENDRESS_HAUSER _DELTBS, DEVICE_REVISION 5, DD_REVISION 1
{
	EVERYTHING;


	REDEFINITIONS
	{

		VARIABLE device_status
		{
			REDEFINE LABEL		[device_status];
			REDEFINE STYLE		"MULTILINE 30 10";//Change002
		}

		VARIABLE measured_parameter
		{
			REDEFINE	LABEL	[V0H0_LABEL_change];
		}

		VARIABLE lower_range_value
		{
			REDEFINE	LABEL	[V0H1_LABEL_change];
			REDEFINE	HELP	[V0_help];
		}

		VARIABLE upper_range_value
		{
			REDEFINE	LABEL	[V0H2_LABEL_change];
			REDEFINE	HELP	[V0_help];
		}

		VARIABLE bias_pressure
		{
			REDEFINE	LABEL	[V0H5_LABEL_change];
			REDEFINE	HELP	[V0_help];
		}

		VARIABLE pressure_damping
		{
			REDEFINE	LABEL	[V0H7_LABEL_change];
		}

		VARIABLE alarm_selection_code_1
		{
			REDEFINE	LABEL	[V0H8_LABEL_change];
		}

		VARIABLE pressure_unit_edit
		{
			REDEFINE	LABEL	[V0H9_LABEL_change];
		}

		VARIABLE diagnostic_code
		{
			REDEFINE	LABEL	[V2H0_LABEL_change];
			ADD			HELP	[V2H0_LABEL_change_help];
			REDEFINE	TYPE ENUMERATED(2)
			{
				DEFAULT_VALUE	0;
				DEF_DIAGNOSTIC_CODE
			}
		}

		VARIABLE last_diagnostic
		{
			REDEFINE	LABEL	[V2H1_LABEL_change];
			ADD			HELP	[V2H0_LABEL_change_help];
			REDEFINE	TYPE ENUMERATED(2)
			{
				DEFAULT_VALUE	0;
				DEF_DIAGNOSTIC_CODE
			}
		}

		VARIABLE instr_and_softw_no
		{
			REDEFINE	LABEL	[V2H2_LABEL_change];
		}

		VARIABLE sensor_pressure_min
		{
			REDEFINE	LABEL	[V2H3_LABEL_change];
		}

		VARIABLE sensor_pressure_max
		{
			REDEFINE	LABEL	[V2H4_LABEL_change];
		}

		VARIABLE int_count_high
		{
			REDEFINE	LABEL	[V2H5_LABEL_change];
		}

		VARIABLE temperature_value
		{
			REDEFINE	LABEL	[V2H6_LABEL_change];
		}

		VARIABLE temperature_value_min
		{
			REDEFINE	LABEL	[V2H7_LABEL_change];
		}

		VARIABLE temperature_value_max
		{
			REDEFINE	LABEL	[V2H8_LABEL_change];
		}

		VARIABLE default_values
		{
			REDEFINE	LABEL	[V2H9_LABEL_change];
//Change002/Change003 start
			TYPE ENUMERATED(2)
			{
				DEFAULT_VALUE	0;
				{ 0,		[no_function]			},
				{ 731,		[default_eh_reset_731]	},
				{ 2380,		[default_eh_reset_2380]	},
				{ 2509,		[default_eh_reset_2509]	},
				{ 5140,		[default_eh_reset_5140]	}
//Change002/Change003 end
			}
		}

		VARIABLE linearisation_mode
		{
			REDEFINE	LABEL	[V3H0_LABEL_change];
			REDEFINE	HELP	[V3H0_LABEL_change_help];
			REDEFINE TYPE ENUMERATED
			{
				{ 0,	"Pressure|de|Druck" },//Change002
				{ 1,	"Square root|049Radizierend"},
				{ 241,	"Level linear|049Fllstand linear"},
				{ 240,	"Level hor. cyl.|049Fllstand zylindrisch liegend"},
				{ 242,	"Level manual|049Fllstand Kennlinie"}
			}

		}
		VARIABLE display_at_04
		{
			REDEFINE	LABEL	[V3H1_LABEL_change];
			ADD VALIDITY IF (linearisation_mode == 0) {FALSE;} ELSE {TRUE;}//Change002
		}
		VARIABLE display_at_20
		{
			REDEFINE	LABEL	[V3H2_LABEL_change];
			ADD VALIDITY IF (linearisation_mode == 0) {FALSE;} ELSE {TRUE;}//Change002
		}
		VARIABLE lin_units_edit
		{
			REDEFINE	LABEL	[V3H3_LABEL_change];
			ADD VALIDITY IF (linearisation_mode == 0) {FALSE;} ELSE {TRUE;}//Change002
		}
		VARIABLE density_factor
		{
			REDEFINE	LABEL	[V3H4_LABEL_change];
			ADD VALIDITY IF (linearisation_mode == 0) {FALSE;} ELSE {TRUE;}//Change002
		}
		VARIABLE creep_flow_supppress
		{
			REDEFINE	LABEL	[V3H5_LABEL_change];
			ADD VALIDITY IF (linearisation_mode == 0) {FALSE;} ELSE {TRUE;}//Change002
		}
		VARIABLE linearization_edit_mode
		{
			REDEFINE	LABEL	[V3H6_LABEL_change];
			REDEFINE	TYPE ENUMERATED
			{
				DEFAULT_VALUE	1;
				{ 0, "ACTIVATE TABLE|049TAB. AKTIVIEREN"},
				{ 1, "MANUAL        |049MANUELL       "},
				{ 2, "SEMIAUTOMATIC |049HALBAUTOMAT. "},
				{ 3, "CLEAR         |049LSCHEN      "}
			}
		}
		VARIABLE xy_table_index
		{
			REDEFINE	LABEL	[V3H7_LABEL_change];
			DELETE POST_EDIT_ACTIONS;
		}
		VARIABLE xy_table_X
		{
			REDEFINE	LABEL	[V3H8_LABEL_change];
			DELETE POST_EDIT_ACTIONS;
		}
		VARIABLE xy_table_Y
		{
			REDEFINE	LABEL	[V3H9_LABEL_change];
			DELETE POST_EDIT_ACTIONS;
		}

		VARIABLE output_current
		{
			REDEFINE	LABEL	[V7H0_LABEL_change];
		}

		VARIABLE switch_sim
		{
			REDEFINE	LABEL	[V7H1_LABEL_change];
			REDEFINE	CLASS DYNAMIC;
		}

		VARIABLE current_low_limit
		{
			REDEFINE	LABEL	[V7H3_LABEL_change];
		}

		VARIABLE low_sensor_cal
		{
			REDEFINE	LABEL	[V7H4_LABEL_change];
		}

		VARIABLE high_sensor_cal
		{
			REDEFINE	LABEL	[V7H5_LABEL_change];
		}

		VARIABLE sensor_lower_limit
		{
			REDEFINE	LABEL	[V7H6_LABEL_change];
		}

		VARIABLE sensor_upper_limit
		{
			REDEFINE	LABEL	[V7H7_LABEL_change];
		}

		VARIABLE sensor_pressure
		{
			REDEFINE	LABEL	[V7H8_LABEL_change];
		}

		VARIABLE temperature_units_edit
		{
			REDEFINE	LABEL	[V7H9_LABEL_change];
		}

		VARIABLE damped_pressure
		{
			REDEFINE	LABEL	[V9H7_LABEL_change];
		}

		VARIABLE bias_damped_pressure
		{
			REDEFINE	LABEL	[V9H8_LABEL_change];
		}

		VARIABLE security_locking
		{
			REDEFINE	LABEL	[V9H9_LABEL_change];
		}

		//Change002: matrix_parameters entfernt; ITEMS siehe Tab_s_EH_Std_Matrix

		MENU TRANSMITTER_INFO
		{
		   REDEFINE LABEL [label_TRANSMITTER_INFO];
		   REDEFINE ITEMS
		   {
			  diagnostic_code,                                           /* VARIABLE */
			  last_diagnostic,		// VARIABLE , last_diag_meth,					
			  instr_and_softw_no,                                        /* VARIABLE */
			  local_sensor_pressure_min,	// VARIABLE , sensor_pres_min_meth,
			  local_sensor_pressure_max,	// VARIABLE , sensor_pres_max_meth,
			  local_int_count_high,		// VARIABLE , int_count_high_meth,
			  temperature_value,                                         /* VARIABLE */
			  local_temperature_value_min,// VARIABLE , temp_value_min_meth,
			  local_temperature_value_max,// VARIABLE , temp_value_max_meth,
			  local_default_values										 /* VARIABLE */
		   }
		}

		MENU LINEARIZATION
		{
			REDEFINE LABEL [label_LINEARIZATION];
			REDEFINE ITEMS
			{
				local_linearisation_mode, //Change003                           /* VARIABLE */
				display_at_04,                                                 /* VARIABLE */
				display_at_20,                                                 /* VARIABLE */
				local_lin_units_edit,//lin_units_edit,                         /* VARIABLE */
				density_factor,                                                /* VARIABLE */
				creep_flow_supppress,                                          /* VARIABLE */
				local_linearization_edit_mode,                           /* VARIABLE */
				local_xy_table_index,                                                /* VARIABLE */
				local_xy_table_X,                                                    /* VARIABLE */
				local_xy_table_Y                                                     /* VARIABLE */
			}
		}

		MENU MEN_SERVICE
		{
		   REDEFINE LABEL "V9 SERVICE|de|V9 SERVICE";
		   REDEFINE ITEMS
		   {
			  damped_pressure,                                               /* VARIABLE */
			  bias_damped_pressure,                                          /* VARIABLE */
			  security_locking		 (READ_ONLY)		                     /* VARIABLE */
		   }
		}

		MENU USER_INFORMATION
		{
			REDEFINE LABEL "VA USER INFORMATION|de|VA BENUTZER INFORMATION";
			REDEFINE ITEMS
			{
				matrix_par1.tag,                                                       /* VARIABLE */
				matrix_par1.user_text,                                                 /* VARIABLE */
				matrix_par1.serial_number,                                             /* VARIABLE */
				matrix_par1.sensor_serial_number_matrix,                               /* VARIABLE */
				matrix_par1.process_connection_p,                                      /* VARIABLE */
				matrix_par1.process_connection_m,                                      /* VARIABLE */
				matrix_par1.gasket,                                                    /* VARIABLE */
				matrix_par1.process_diaphragma,                                        /* VARIABLE */
				matrix_par1.fill_liquit                                                /* VARIABLE */
			}
		}

		MENU ADDITIONAL_FUNCTION
		{
		   LABEL "V7 ADDITIONAL FUNCT.|de|V7 ZUSATZ FUNKTIONEN";
		   ITEMS
		   {
			output_current,                                            /* VARIABLE */
			//sim_current											   /* METHOD   */
			local_switch_sim,
			local_simulation_current,
			current_low_limit,                                         /* VARIABLE */
			local_automatic_low_sensor_cal,  //automatic_low_sensor_cal/* METHOD   */
			local_automatic_high_sensor_cal,//automatic_high_sensor_cal/* METHOD   */
			sensor_lower_limit,                                        /* VARIABLE */
			sensor_upper_limit,                                        /* VARIABLE */
			sensor_pressure,                                           /* VARIABLE */
			local_temperature_units_edit                               /* VARIABLE */

		   }
		}

		MENU CALIBRATION
		{
		   REDEFINE LABEL [label_CALIBRATION];
		   REDEFINE ACCESS ONLINE;
		   REDEFINE ITEMS
		   {
			  measured_parameter,                                        /* VARIABLE */
			  lower_range_value	(READ_ONLY),                             /* VARIABLE */
			  upper_range_value	(READ_ONLY),                             /* VARIABLE */
			  local_automatic_4mA_V0H3, //automatic_4mA					 /* METHOD   */
			  local_automatic_20mA_V0H4, //automatic_20mA				 /* METHOD   */
			  bias_pressure 	(READ_ONLY),                             /* VARIABLE */
			  local_automatic_bias_V0H6, //automatic_bias,               /* METHOD   */
			  pressure_damping,                                          /* VARIABLE */
			  alarm_selection_code_1,                                    /* VARIABLE */
			  local_pressure_unit_edit,									 /* VARIABLE */
			  method_set,
				SEPARATOR,
				meth_invisible,
				meth_lower_range_value,
				meth_upper_range_value,
				meth_invisible,
				meth_invisible,
				meth_bias_pressure,
		   }
		}

		MENU upload_variables
		{
		   REDEFINE ITEMS
		   {
				tag,
				descriptor,
				message,
				final_assembly_number,
				date,
				user_text,
				density_factor,
				creep_flow_supppress,

				//pressure_unit_edit,		//OnlineDialog_pressure_unit_edit
				//temperature_units_edit,	//OnlineDialog_temperature_units_edit
				//lin_units_edit,			//OnlineDialog_lin_units_edit

				//bias_pressure,		//meth_bias_pressure
				//lower_range_value,	//meth_lower_range_value
				//upper_range_value,	//meth_upper_range_value

				pressure_damping,
				alarm_selection_code_1,
				last_diagnostic,

				current_low_limit,

				display_at_04,
				display_at_20,
				/* OnlineDialog_linear:
				xy_table_index,
				IF (linearization_edit_mode == 1)
				{
					xy_table_X,
				}
				IF (linearization_edit_mode == 1 || linearization_edit_mode == 2)
				{
					xy_table_Y,
				}
				*/

				process_connection_p,
				process_connection_m,
				gasket,
				process_diaphragma,
				fill_liquit,


			  //polling_address
		   }
		}

		METHOD abort_simulation
		{
		   REDEFINE LABEL "ABORT SIMULATION|049BEENDIGUNG SIM.";
		}

		METHOD automatic_bias
		{
		 REDEFINE DEFINITION
		 {
			int rc;
			long varid[3];
			char status[STATUS_SIZE];
			IGNORE_ALL_RESPONSE_CODES();

			varid[0] =VARID(damped_pressure);
			varid[1] =VARID(pressure_unit);
			//while ( 1 ) //Endlos-Schleife
			//{
			   do
			   {
				  iassign(variable_array_index,0x97);           /* damped pressure */
				  send(144,status);                             /* read value      */
				  rc = select_from_list(prompt_process,varid,select_bias);
			   } while(rc==1);
			   if( rc == 0 )
			   {
				  send(43,status);

				  if ( status[STATUS_RESPONSE_CODE] )
				  {
					 display_response_status(43,status[STATUS_RESPONSE_CODE]);
				  }
												 /* read bias pressure from device */
				  iassign(variable_array_index,0x05);        /* bias pressure      */
				  send(144,status);                          /* read value         */
				  if ( status[STATUS_RESPONSE_CODE] )
				  {
					 display_response_status(144,status[STATUS_RESPONSE_CODE]);
				  }

											 /* read LRV and URV again from device */
				  iassign(variable_array_index,0x01);        /* lower ranger value */
				  send(144,status);                          /* read value         */
				  if ( status[STATUS_RESPONSE_CODE] )
				  {
					 display_response_status(144,status[STATUS_RESPONSE_CODE]);
				  }

				  iassign(variable_array_index,0x02);        /* upper ranger value */
				  send(144,status);                          /* read value         */
				  if ( status[STATUS_RESPONSE_CODE] )
				  {
					 display_response_status(144,status[STATUS_RESPONSE_CODE]);
				  }
			   }
			//}
		 }
		}


		METHOD automatic_4mA
		{
		 REDEFINE DEFINITION
		 {
			int rc;
			long varid[3];
			char status[STATUS_SIZE];
			IGNORE_ALL_RESPONSE_CODES();

			varid[0] =VARID(bias_damped_pressure);
			varid[1] =VARID(pressure_unit);
			//while ( 1 ) //Endlos-Schleife
			//{
			  do
			   {
				  iassign(variable_array_index,0x98);           /* bias damped pressure */
				  send(144,status);
				  rc = select_from_list(prompt_process,varid,select_4mA);
			   } while(rc==1);
			   if( rc == 0 )
			   {
				  send(37,status);
				  if ( status[STATUS_RESPONSE_CODE] )
				  {
					 display_response_status(37,status[STATUS_RESPONSE_CODE]);
				  }
													 /* read LRV again from device */
				  iassign(variable_array_index,0x01);        /* upper ranger value */
				  send(144,status);                          /* read value         */
				  if ( status[STATUS_RESPONSE_CODE] )
				  {
					 display_response_status(144,status[STATUS_RESPONSE_CODE]);
				  }
													 /* read URV again from device */
				  iassign(variable_array_index,0x02);        /* upper ranger value */
				  send(144,status);                          /* read value         */
				  if ( status[STATUS_RESPONSE_CODE] )
				  {
					 display_response_status(144,status[STATUS_RESPONSE_CODE]);
				  }
			   }
			//}
		 }
		}

		METHOD automatic_20mA
		{
		 REDEFINE DEFINITION
		 {
			int rc;
			long varid[3];
			char status[STATUS_SIZE];
			IGNORE_ALL_RESPONSE_CODES();

			varid[0] =VARID(bias_damped_pressure);
			varid[1] =VARID(pressure_unit);
			//while ( 1 ) //Endlos-Schleife
			//{
			   do
			   {
				  iassign(variable_array_index,0x98);          /* bias damped pressure */
				  send(144,status);
				  rc = select_from_list(prompt_process,varid,select_20mA);
			   } while(rc==1);
			   if( rc == 0 )
			   {
				  send(36,status);                        /* set upper range value */
				  if ( status[STATUS_RESPONSE_CODE] )
				  {
					 display_response_status(36,status[STATUS_RESPONSE_CODE]);
				  }
													 /* read LRV again from device */
				  iassign(variable_array_index,0x01);        /* upper ranger value */
				  send(144,status);                          /* read value         */
				  if ( status[STATUS_RESPONSE_CODE] )
				  {
					 display_response_status(144,status[STATUS_RESPONSE_CODE]);
				  }
													 /* read URV again from device */
				  iassign(variable_array_index,0x02);        /* upper ranger value */
				  send(144,status);                          /* read value         */
				  if ( status[STATUS_RESPONSE_CODE] )
				  {
					 display_response_status(144,status[STATUS_RESPONSE_CODE]);
				  }
			   }
			//}
		 }
		}

		METHOD sim_current
		{
			REDEFINE DEFINITION
		   {
			  char status[STATUS_SIZE];

			  IGNORE_ALL_RESPONSE_CODES();
			  IGNORE_ALL_DEVICE_STATUS();
			  XMTR_IGNORE_ALL_DEVICE_STATUS();
			  add_abort_method(abort_simulation);

			  assign_int(switch_sim,1);                      /* switch simulation on */
			  iassign(variable_array_index,0x71);
			  send(145,status);                               /* send info to device */
			  if ( status[STATUS_RESPONSE_CODE] )
			  {
				 remove_abort_method(abort_simulation);
				 display_response_status(145,status[STATUS_RESPONSE_CODE]);
			  }
			  else
			  {
				 //while ( 1 )
				 //{
					GET_DEV_VAR_VALUE("SIM. CURRENT|049SIM. STROMAUSGANG",simulation_current);
					iassign(variable_array_index,0x72);
					send(145,status);
					if ( status[STATUS_RESPONSE_CODE] )
					{
					   display_response_status(145,status[STATUS_RESPONSE_CODE]);
					}
				 //}
			  }
		   }
		}

		METHOD last_diag_meth
		{
			REDEFINE DEFINITION
			{
			  int rc;
			  long varid[3];
			  char status[STATUS_SIZE];

			  IGNORE_ALL_RESPONSE_CODES();
			  IGNORE_ALL_DEVICE_STATUS();
			  XMTR_IGNORE_ALL_DEVICE_STATUS();
			  add_abort_method(abort_dynamic);

			  varid[0] =VARID(last_diagnostic);
			  iassign(variable_array_index,0x21);

			  //while(1)
			  //{
				 send(144,status);
				 if ( status[STATUS_RESPONSE_CODE] )
				 {
					display_response_status(144,status[STATUS_RESPONSE_CODE]);
				 }

				 delay(3,"LAST DIAGNOSTIC      >%{0}|049LETZT. DIAGN. CODE   >%{0}",varid);
			  //}
			}
		}

		METHOD sensor_pres_min_meth
		{
			REDEFINE DEFINITION
			{
			  int rc;
			  long varid[3];
			  char status[STATUS_SIZE];

			  IGNORE_ALL_RESPONSE_CODES();
			  IGNORE_ALL_DEVICE_STATUS();
			  XMTR_IGNORE_ALL_DEVICE_STATUS();
			  add_abort_method(abort_dynamic);

			  varid[0] =VARID(sensor_pressure_min);
			  varid[1] =VARID(pressure_unit);
			  iassign(variable_array_index,0x23);

			  //while(1)
			  //{
				 send(144,status);
				 if ( status[STATUS_RESPONSE_CODE] )
				 {
					display_response_status(144,status[STATUS_RESPONSE_CODE]);
				 }

				 delay(3,"MIN. PRESSURE        >%{0} %{1}|049MIN. DRUCK           >%{0} %{1}",varid);
			  //}
			}
		}

		METHOD sensor_pres_max_meth
		{
			REDEFINE DEFINITION
			{
			  int rc;
			  long varid[3];
			  char status[STATUS_SIZE];

			  IGNORE_ALL_RESPONSE_CODES();
			  IGNORE_ALL_DEVICE_STATUS();
			  XMTR_IGNORE_ALL_DEVICE_STATUS();
			  add_abort_method(abort_dynamic);

			  varid[0] =VARID(sensor_pressure_max);
			  varid[1] =VARID(pressure_unit);
			  iassign(variable_array_index,0x24);

			  //while(1)
			  //{
				 send(144,status);
				 if ( status[STATUS_RESPONSE_CODE] )
				 {
					display_response_status(144,status[STATUS_RESPONSE_CODE]);
				 }

				 delay(3,"MAX. PRESSURE        >%{0} %{1}|049MAX. DRUCK           >%{0} %{1}",varid);
			  //}
			}
		}

		METHOD int_count_high_meth
		{
			REDEFINE DEFINITION
			{
			  int rc;
			  long varid[3];
			  char status[STATUS_SIZE];

			  IGNORE_ALL_RESPONSE_CODES();
			  IGNORE_ALL_DEVICE_STATUS();
			  XMTR_IGNORE_ALL_DEVICE_STATUS();
			  add_abort_method(abort_dynamic);

			  varid[0] =VARID(int_count_high);
			  iassign(variable_array_index,0x25);

			  //while(1)
			  //{
				 send(144,status);
				 if ( status[STATUS_RESPONSE_CODE] )
				 {
					display_response_status(144,status[STATUS_RESPONSE_CODE]);
				 }

				 delay(3,"INT. COUNTER HIGH     %{0}|049INT. ZAEHLER HIGH     %{0}",varid);
			  //}
			}
		}

		METHOD temp_value_min_meth
		{
			REDEFINE DEFINITION
			{
			  int rc;
			  long varid[3];
			  char status[STATUS_SIZE];

			  IGNORE_ALL_RESPONSE_CODES();
			  IGNORE_ALL_DEVICE_STATUS();
			  XMTR_IGNORE_ALL_DEVICE_STATUS();
			  add_abort_method(abort_dynamic);

			  varid[0] =VARID(temperature_value_min);
			  varid[1] =VARID(temperature_units);
			  iassign(variable_array_index,0x27);

			  //while(1)
			  //{
				 send(144,status);
				 if ( status[STATUS_RESPONSE_CODE] )
				 {
					display_response_status(144,status[STATUS_RESPONSE_CODE]);
				 }

				 delay(3,"MIN. TEMPERATURE     >%{0} %{1}|049MIN. TEMPERATUR      >%{0} %{1}",varid);
			  //}
			}
		}

		METHOD temp_value_max_meth
		{
			REDEFINE DEFINITION
			{
			  int rc;
			  long varid[3];
			  char status[STATUS_SIZE];

			  IGNORE_ALL_RESPONSE_CODES();
			  IGNORE_ALL_DEVICE_STATUS();
			  XMTR_IGNORE_ALL_DEVICE_STATUS();
			  add_abort_method(abort_dynamic);

			  varid[0] =VARID(temperature_value_max);
			  varid[1] =VARID(temperature_units);
			  iassign(variable_array_index,0x28);

			  //while(1)
			  //{
				 send(144,status);
				 if ( status[STATUS_RESPONSE_CODE] )
				 {
					display_response_status(144,status[STATUS_RESPONSE_CODE]);
				 }

				 delay(3,"MAX. TEMPERATURE     >%{0} %{1}|049MAX. TEMPERATUR      >%{0} %{1}",varid);
			  //}
			}
		}

      METHOD automatic_low_sensor_cal
      {
         REDEFINE DEFINITION
         {
            float fval;
            int  rc;
            long varid[3];
            char status[STATUS_SIZE];
            char disp_string1[60];
            int slen1;

            slen1=60;

            IGNORE_ALL_RESPONSE_CODES();

            get_dictionary_string(press_ok_when_pressure_stable,disp_string1,slen1);
            ACKNOWLEDGE(disp_string1);

            varid[0] = VARID(damped_pressure);
            varid[1] = VARID(pressure_unit);

            fval = float_value(low_sensor_cal);

            iassign(variable_array_index,0x97);                 /* damped pressure */
            send(144,status);                                   /* read value      */

            rc = get_local_var_value(prompt_low_sens,varid,fval);
            if (rc == BI_SUCCESS)
            {
               assign_float(low_sensor_cal,fval);
               iassign(variable_array_index,0x74);
               send(145,status);
               if ( status[STATUS_RESPONSE_CODE] )
               {
                  display_response_status(145,status[STATUS_RESPONSE_CODE]);
               }
            }
         }
      }

      METHOD automatic_high_sensor_cal
      {
         REDEFINE DEFINITION
         {
            float fval;
            int  rc;
            long varid[3];
            char status[STATUS_SIZE];
            char disp_string1[60];
            int slen1;

            slen1=60;

            IGNORE_ALL_RESPONSE_CODES();

            get_dictionary_string(press_ok_when_pressure_stable,disp_string1,slen1);
            ACKNOWLEDGE(disp_string1);

            varid[0] = VARID(damped_pressure);
            varid[1] = VARID(pressure_unit);

            fval = float_value(high_sensor_cal);

            iassign(variable_array_index,0x97);                 /* damped pressure */
            send(144,status);                                   /* read value      */

            rc = get_local_var_value(prompt_high_sens,varid,fval);
            if (rc == BI_SUCCESS)
            {
               assign_float(high_sensor_cal,fval);
               iassign(variable_array_index,0x75);
               send(145,status);
               if ( status[STATUS_RESPONSE_CODE] )
               {
                  display_response_status(145,status[STATUS_RESPONSE_CODE]);
               }
            }
         }
      }


	}
}

// unsichtbarer Button
METHOD	meth_invisible
{
	LABEL		"";
	DEFINITION{}
	VALIDITY	FALSE;
}

VARIABLE local_automatic_4mA_V0H3
{
	LABEL	[V0H3_LABEL_change];
	CLASS LOCAL;
	TYPE ENUMERATED
	{
		DEFAULT_VALUE	0;
		{	0,	[enum_calib_proc]	}
	}
	HANDLING	READ;
}

VARIABLE local_automatic_20mA_V0H4
{
	LABEL	[V0H4_LABEL_change];
	CLASS LOCAL;
	TYPE ENUMERATED
	{
		DEFAULT_VALUE	0;
		{	0,	[enum_calib_proc]	}
	}
	HANDLING	READ;
}

VARIABLE local_automatic_bias_V0H6
{
	LABEL	[V0H6_LABEL_change];
	CLASS LOCAL;
	TYPE ENUMERATED
	{
		DEFAULT_VALUE	0;
		{	0,	[enum_calib_proc]	}
	}
	HANDLING	READ;
}

VARIABLE local_pressure_unit_edit
{
	LABEL	[V0H9_LABEL_change];
	CLASS LOCAL;
	TYPE ENUMERATED
	{
		DEFAULT_VALUE	0;
		{	0,	[enum_system_units]	}
	}
	HANDLING	READ;
}

VARIABLE local_temperature_units_edit
{
	LABEL	[V7H9_LABEL_change];
	CLASS LOCAL;
	TYPE ENUMERATED
	{
		DEFAULT_VALUE	0;
		{	0,	[enum_system_units]	}
	}
	HANDLING	READ;
}

VARIABLE local_sensor_pressure_min
{
	LABEL	[V2H3_LABEL_change];
	CLASS LOCAL;
	TYPE ENUMERATED
	{
		DEFAULT_VALUE	0;
		{	0,	[enum_indicators]	}
	}
	HANDLING	READ;
}

local_sensor_pressure_max LIKE VARIABLE local_sensor_pressure_min
{
	REDEFINE LABEL	[V2H4_LABEL_change];
}

local_temperature_value_min LIKE VARIABLE local_sensor_pressure_min
{
	REDEFINE LABEL	[V2H7_LABEL_change];
}

local_temperature_value_max LIKE VARIABLE local_sensor_pressure_min
{
	REDEFINE LABEL	[V2H8_LABEL_change];
}

VARIABLE local_int_count_high
{
	LABEL	[V2H5_LABEL_change];
	CLASS LOCAL;
	TYPE ENUMERATED
	{
		DEFAULT_VALUE	0;
		{	0,	[enum_int_count_high]	}
	}
	HANDLING	READ;
}

VARIABLE local_default_values
{
	LABEL	[V2H9_LABEL_change];
	CLASS LOCAL;
	TYPE ENUMERATED
	{
		DEFAULT_VALUE	0;
		{	0,	[enum_default_values]	}
	}
	HANDLING	READ;
}

VARIABLE local_lin_units_edit
{
	LABEL	[V3H3_LABEL_change];
	CLASS LOCAL;
	TYPE ENUMERATED
	{
		DEFAULT_VALUE	0;
		{	0,	[enum_system_units]	}
	}
	HANDLING	READ;
	VALIDITY IF (linearisation_mode == 0) {FALSE;} ELSE {TRUE;}//Change002
}

VARIABLE local_linearization_edit_mode
{
	LABEL	[V3H6_LABEL_change];
	CLASS LOCAL;
	TYPE ENUMERATED
	{
		DEFAULT_VALUE	0;
		{	0,	[enum_linearization]	}
	}
	HANDLING	READ;
}

local_xy_table_index LIKE VARIABLE local_linearization_edit_mode
{
	REDEFINE LABEL	[V3H7_LABEL_change];
}

local_xy_table_X LIKE VARIABLE local_linearization_edit_mode
{
	REDEFINE LABEL	[V3H8_LABEL_change];
}

local_xy_table_Y LIKE VARIABLE local_linearization_edit_mode
{
	REDEFINE LABEL	[V3H9_LABEL_change];
}

VARIABLE local_switch_sim
{
	LABEL	[V7H1_LABEL_change];
	CLASS LOCAL;
	TYPE ENUMERATED
	{
		DEFAULT_VALUE	0;
		{	0,	[enum_simulation]	}
	}
	HANDLING	READ;
}

VARIABLE local_simulation_current
{
	LABEL	[V7H2_LABEL_change];
	CLASS LOCAL;
	TYPE ENUMERATED
	{
		DEFAULT_VALUE	0;
		{	0,	[enum_simulation]	}
	}
	HANDLING	READ;
}

VARIABLE local_automatic_low_sensor_cal
{
	LABEL	[V7H4_LABEL_change];
	CLASS LOCAL;
	TYPE ENUMERATED
	{
		DEFAULT_VALUE	0;
		{	0,	[enum_calib_proc]	}
	}
	HANDLING	READ;
}

VARIABLE local_automatic_high_sensor_cal
{
	LABEL	[V7H5_LABEL_change];
	CLASS LOCAL;
	TYPE ENUMERATED
	{
		DEFAULT_VALUE	0;
		{	0,	[enum_calib_proc]	}
	}
	HANDLING	READ;
}

//Change003 start
local_linearisation_mode LIKE VARIABLE linearisation_mode
{
	REDEFINE CLASS LOCAL;
	REDEFINE TYPE ENUMERATED
	{
		DEFAULT_VALUE	0;
		{	0,	[enum_lin_mode]	}
	}
	REDEFINE	HANDLING	READ;
}
//Change003 end

METHOD meth_abort
{
	DEFINITION
	{
		ACKNOWLEDGE([acknowledge_process_aborted]);
	}
}

METHOD	meth_lower_range_value
{
	LABEL		[meth_change];
	DEFINITION
	{
		int ret;
		long var_id[1];
		char status[STATUS_SIZE];

		add_abort_method (meth_abort);

		var_id[0] = VARID(pressure_unit);
		ret = get_dev_var_value([ack_choice_lrv], var_id, lower_range_value);
		if (ret)	process_abort();	// ok <=> 0

		/* write LRV  */
		iassign(variable_array_index,0x01);        /* lower ranger value */
		send(145,status);
		if ( status[STATUS_RESPONSE_CODE] )
		{
		 display_response_status(145,status[STATUS_RESPONSE_CODE]);
		}
										 /* read LRV again from device */
		iassign(variable_array_index,0x01);        /* upper ranger value */
		send(144,status);                          /* read value         */
		if ( status[STATUS_RESPONSE_CODE] )
		{
		 display_response_status(144,status[STATUS_RESPONSE_CODE]);
		}
										 /* read URV again from device */
		iassign(variable_array_index,0x02);        /* upper ranger value */
		send(144,status);                          /* read value         */
		if ( status[STATUS_RESPONSE_CODE] )
		{
		 display_response_status(144,status[STATUS_RESPONSE_CODE]);
		}

									 /* read bias pressure from device */
		iassign(variable_array_index,0x05);        /* bias pressure      */
		send(144,status);                          /* read value         */
		if ( status[STATUS_RESPONSE_CODE] )
		{
		 display_response_status(144,status[STATUS_RESPONSE_CODE]);
		}

	}
}

METHOD	meth_upper_range_value
{
	LABEL		[meth_change];
	DEFINITION
	{
		int ret;
		long var_id[1];
		char status[STATUS_SIZE];

		add_abort_method (meth_abort);

		var_id[0] = VARID(pressure_unit);
		ret = get_dev_var_value([ack_choice_urv], var_id, upper_range_value);
		if (ret)	process_abort();	// ok <=> 0

		/* write URV  */
		iassign(variable_array_index,0x02);        /* upper ranger value */
		send(145,status);
		if ( status[STATUS_RESPONSE_CODE] )
		{
		 display_response_status(145,status[STATUS_RESPONSE_CODE]);
		}
										 /* read LRV again from device */
		iassign(variable_array_index,0x01);        /* upper ranger value */
		send(144,status);                          /* read value         */
		if ( status[STATUS_RESPONSE_CODE] )
		{
		 display_response_status(144,status[STATUS_RESPONSE_CODE]);
		}
										 /* read URV again from device */
		iassign(variable_array_index,0x02);        /* upper ranger value */
		send(144,status);                          /* read value         */
		if ( status[STATUS_RESPONSE_CODE] )
		{
		 display_response_status(144,status[STATUS_RESPONSE_CODE]);
		}

									 /* read bias pressure from device */
		iassign(variable_array_index,0x05);        /* bias pressure      */
		send(144,status);                          /* read value         */
		if ( status[STATUS_RESPONSE_CODE] )
		{
		 display_response_status(144,status[STATUS_RESPONSE_CODE]);
		}
	}
}

METHOD	meth_bias_pressure
{
	LABEL		[meth_change];
	DEFINITION
	{
		int ret;
		long var_id[1];
		char status[STATUS_SIZE];

		add_abort_method (meth_abort);

		var_id[0] = VARID(pressure_unit);
		ret = get_dev_var_value([ack_choice_bias_press], var_id, bias_pressure);
		if (ret)	process_abort();	// ok <=> 0

		/* write bias_pressure  */
		iassign(variable_array_index,0x05);        /*  bias_pressure  value */
		send(145,status);
		if ( status[STATUS_RESPONSE_CODE] )
		{
		 display_response_status(145,status[STATUS_RESPONSE_CODE]);
		}
										 /* read LRV again from device */
		iassign(variable_array_index,0x01);        /* upper ranger value */
		send(144,status);                          /* read value         */
		if ( status[STATUS_RESPONSE_CODE] )
		{
		 display_response_status(144,status[STATUS_RESPONSE_CODE]);
		}
										 /* read URV again from device */
		iassign(variable_array_index,0x02);        /* upper ranger value */
		send(144,status);                          /* read value         */
		if ( status[STATUS_RESPONSE_CODE] )
		{
		 display_response_status(144,status[STATUS_RESPONSE_CODE]);
		}

									 /* read bias pressure from device */
		iassign(variable_array_index,0x05);        /* bias pressure      */
		send(144,status);                          /* read value         */
		if ( status[STATUS_RESPONSE_CODE] )
		{
		 display_response_status(144,status[STATUS_RESPONSE_CODE]);
		}
	}
}

METHOD reset_pressure_pointer
{
	LABEL	[reset]; 
	HELP	[reset_pres_pointer_Help];
	DEFINITION
	{
		char status[STATUS_SIZE];
		int choice_mode, choise_reset;

		choice_mode= SELECT_FROM_LIST([select_to_reset], [maxmin_R]);

		choise_reset = SELECT_FROM_LIST ([ack_reset], [no_yes]);
		switch (choise_reset)                          
		{                                        
			case 0:                              
					ACKNOWLEDGE([acknowledge_process_aborted]);
			break;                               
			case 1:                               
			switch (choice_mode)
			{
				case 0: 
					iassign(variable_array_index,0x24);        /*  sensor_pressure_max */
					send(145,status);
					if ( status[STATUS_RESPONSE_CODE] )
					{
						display_response_status(145,status[STATUS_RESPONSE_CODE]);
					}
					else
						ACKNOWLEDGE([acknowledge_pointer_max_reset]);  

				break;
				case 1:
					iassign(variable_array_index,0x23);        /*  sensor_pressure_min */
					send(145,status);
					if ( status[STATUS_RESPONSE_CODE] )
					{
						display_response_status(145,status[STATUS_RESPONSE_CODE]);
					}
					else
						ACKNOWLEDGE([acknowledge_pointer_min_reset]);  
				break;
				case 2:
					iassign(variable_array_index,0x23);        /*  sensor_pressure_min */
					send(145,status);
					if ( status[STATUS_RESPONSE_CODE] )
					{
						display_response_status(145,status[STATUS_RESPONSE_CODE]);
					}
					else
					{
						iassign(variable_array_index,0x24);        /*  sensor_pressure_max */
						send(145,status);
						if ( status[STATUS_RESPONSE_CODE] )
						{
							display_response_status(145,status[STATUS_RESPONSE_CODE]);
						}
						else
							ACKNOWLEDGE([acknowledge_pointer_max_min_reset]);  
					}
				break;
			}//switch (choice_mode)
			break;
		}
	}
} 

METHOD reset_temperature_pointer
{
	LABEL	[reset]; 
	HELP	[reset_pres_pointer_Help];
	DEFINITION
	{
		char status[STATUS_SIZE];
		int choice_mode, choise_reset;

		choice_mode= SELECT_FROM_LIST([select_to_reset], [maxmin_R]);

		choise_reset = SELECT_FROM_LIST ([ack_reset], [no_yes]);
		switch (choise_reset)                          
		{                                        
			case 0:                              
					ACKNOWLEDGE([acknowledge_process_aborted]);
			break;                               
			case 1:                               
			switch (choice_mode)
			{
				case 0: 
					iassign(variable_array_index,0x28);        /*  temperature_value_max */
					send(145,status);
					if ( status[STATUS_RESPONSE_CODE] )
					{
						display_response_status(145,status[STATUS_RESPONSE_CODE]);
					}
					else
						ACKNOWLEDGE([acknowledge_pointer_max_reset]);  

				break;
				case 1:
					iassign(variable_array_index,0x27);        /*  temperature_value_min */
					send(145,status);
					if ( status[STATUS_RESPONSE_CODE] )
					{
						display_response_status(145,status[STATUS_RESPONSE_CODE]);
					}
					else
						ACKNOWLEDGE([acknowledge_pointer_min_reset]);  
				break;
				case 2:
					iassign(variable_array_index,0x27);        /*  temperature_value_min */
					send(145,status);
					if ( status[STATUS_RESPONSE_CODE] )
					{
						display_response_status(145,status[STATUS_RESPONSE_CODE]);
					}
					else
					{
						iassign(variable_array_index,0x28);        /*  temperature_value_max */
						send(145,status);
						if ( status[STATUS_RESPONSE_CODE] )
						{
							display_response_status(145,status[STATUS_RESPONSE_CODE]);
						}
						else
							ACKNOWLEDGE([acknowledge_pointer_max_min_reset]);  
					}
				break;
			}//switch (choice_mode)
			break;
		}
	}
} 



COLLECTION OF VARIABLE matrix_par1
{

    MEMBERS
    {
	tag,tag,															[VAH0_LABEL_change];
	user_text,user_text,												[VAH1_LABEL_change];
	serial_number,serial_number,															[VAH2_LABEL_change];
	sensor_serial_number_matrix,sensor_serial_number_matrix,			[VAH3_LABEL_change];
	process_connection_p,process_connection_p,							[VAH4_LABEL_change];
	process_connection_m,process_connection_m,							[VAH5_LABEL_change];
	gasket,gasket,														[VAH6_LABEL_change];
	process_diaphragma,process_diaphragma,								[VAH7_LABEL_change];
	fill_liquit,fill_liquit,											[VAH8_LABEL_change];

	}
}

